==> corhel-2.1.tar.gz: CORHEL-2.1/tools/helio/set.sh <==
#!/bin/csh
#---------------------------------------------------------------------------
# set.sh: Set environment variables to compile and run ENLIL computations.
#
# Usage: source ./set.sh [mode]
#     [mode] is either 'make' or 'run'.
#---------------------------------------------------------------------------

# Checking argument
if ($#argv != 1 || ($1 != 'make' && $1 != 'run')) then
  echo "set.sh: Set environment variables to compile and run MAS computations."
  echo ""
  echo "Usage: source ./set.sh [mode]"
  echo "    [mode] is either 'make' or 'run'."
  exit 1
endif

# Checking system platform
if (`uname` == 'Linux') then
  set compiler = "ifort"
  set system = "linux"
else if (`uname` == 'Darwin') then
  set compiler = "xlf95_r"
  set system = "macosx"
else
  echo "ERROR: Unsupported platform"
  exit 1
endif

# Set directories
setenv ENLIL_DIR  "`pwd`"
setenv ENLIL_BIN  "`pwd`/bin/$system"
setenv ENLIL_DATA "`pwd`/data"
setenv NETCDF_DIR "`pwd`/lib/$system"

# Rerun ranlib just in case after copying CORHEL-2.1
pushd lib/$system/lib > /dev/null
foreach lib (*.a)
  ranlib $lib 
end
popd > /dev/null


#--------------------------------------------------------------------------
# Things needed to be set for compilation.
#--------------------------------------------------------------------------
if ($1 == 'make') then

  # Checking fortran compiler
  set fortran = `which $compiler`
  if ($#fortran != 1) then
    echo "ERROR: $compiler is required, but not found"
    exit 1
  endif

  # Set environment variables
  setenv SYSTEM "$system"
  setenv F90 "$fortran"
  if ($compiler == 'ifort') then
    setenv F90FLAGS "-O3 -free"
    setenv CPPFLAGS "-DNDEBUG -DpgiFortran"
    setenv LDFLAGS "-static"
  else
    setenv F90FLAGS "-O3 -qnosave -qstrict"
    setenv CPPFLAGS "DIBMR2Fortran"
    setenv LDFLAGS ""
  endif

endif


#--------------------------------------------------------------------------
# Things needed to be set for running execution.
#--------------------------------------------------------------------------
if ($1 == 'run') then

  if ($system == 'macosx') then
    setenv DYLD_LIBRARY_PATH
    setenv DYLD_LIBRARY_PATH "$NETCDF_DIR"
  endif

endif

==> corhel-2.3.tar.gz: CORHEL-2.3/tools/helio/set.sh <==
#!/bin/csh
#---------------------------------------------------------------------------
# set.sh: Set environment variables to compile and run ENLIL computations.
#
# Usage: set.sh <make | run>
#---------------------------------------------------------------------------

# Checking argument
if ($#argv != 1 || ($1 != 'make' && $1 != 'run')) then
  echo "Usage: set.sh <make | run>"
  exit 1
endif

# Checking system platform
if (`uname` == 'Linux') then
  set compiler = "ifort"
  set system = "linux"
else if (`uname` == 'Darwin') then
  set compiler = "xlf95_r"
  set system = "macosx"
else
  echo "ERROR: Unsupported platform"
  exit 1
endif

# Set directories
setenv ENLIL_DIR  "`pwd`"
setenv ENLIL_BIN  "`pwd`/bin/$system"
setenv NETCDF_DIR "`pwd`/lib/$system"

# Rerun ranlib just in case after copying
pushd lib/$system/lib > /dev/null
foreach lib (*.a)
  ranlib $lib 
end
popd > /dev/null


#--------------------------------------------------------------------------
# Things needed to be set for compilation.
#--------------------------------------------------------------------------
if ($1 == 'make') then

  # Checking fortran compiler
  set fortran = `which $compiler`
  if ($#fortran != 1) then
    echo "ERROR: $compiler is required, but not found"
    exit 1
  endif

  # Set environment variables
  setenv SYSTEM "$system"
  setenv F90 "$fortran"
  if ($compiler == 'ifort') then
    setenv F90FLAGS "-O3 -free"
    setenv CPPFLAGS "-DNDEBUG"
    setenv LDFLAGS "-static"
  else
    setenv F90FLAGS "-O3 -qnosave -qstrict"
    setenv CPPFLAGS "-DNDEBUG"
    setenv LDFLAGS ""
  endif

endif


#--------------------------------------------------------------------------
# Things needed to be set for running execution.
#--------------------------------------------------------------------------
if ($1 == 'run') then

  if ($system == 'macosx') then
    setenv DYLD_LIBRARY_PATH
    setenv DYLD_LIBRARY_PATH "$NETCDF_DIR"
  endif

endif
